Please see [https://docs.mlcommons.org/cm4mlops/scripts/Reproduce-MLPerf-benchmarks/wrapper-reproduce-octoml-tinyml-submission](https://docs.mlcommons.org/cm4mlops/scripts/Reproduce-MLPerf-benchmarks/wrapper-reproduce-octoml-tinyml-submission) for the documentation of this CM script.
